@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 from django.dispatch import Signal
 
+# Signals emitted before and after preparing a Django form class from a BaseForm.
+pre_form_class_prepare = Signal()
+post_form_class_prepare = Signal()
+
 # Signals emitted before and after initializing a Record form.
 pre_form_init = Signal()
 post_form_init = Signal()
